@@ -1,6 +1,6 @@
 package Bio::FastParsers::Blast::Xml;
-# ABSTRACT: front-end class for XML BLAST parser
-$Bio::FastParsers::Blast::Xml::VERSION = '0.180330';
+# ABSTRACT: Front-end class for XML BLAST parser
+$Bio::FastParsers::Blast::Xml::VERSION = '0.180470';
 use Moose;
 use namespace::autoclean;
 
@@ -23,7 +23,7 @@ has 'blast_output' => (
     init_arg => undef,
     lazy     => 1,
     builder  => '_build_blast_output',
-);  
+);
 
 ## no critic (ProhibitUnusedPrivateSubroutines)
 
@@ -39,7 +39,7 @@ sub _build_blast_output {
         carp "Warning: '$file' unexpectedly empty; returning no BlastOutput!";
         return;
     }
-    
+
     return BlastOutput->new( _root => $bo );
 }
 
@@ -55,11 +55,11 @@ __END__
 
 =head1 NAME
 
-Bio::FastParsers::Blast::Xml - front-end class for XML BLAST parser
+Bio::FastParsers::Blast::Xml - Front-end class for XML BLAST parser
 
 =head1 VERSION
 
-version 0.180330
+version 0.180470
 
 =head1 SYNOPSIS
 
@@ -113,7 +113,29 @@ version 0.180330
 
 =head1 DESCRIPTION
 
-    # TODO
+This module implements a parser for the XML output format of the BLAST program
+(e.g., C<-outfmt 5>). It provides methods for iterating over and querying all
+elements of the XML tree. The hierarchy is as follows:
+
+=over
+
+=item L<Bio::FastParsers::Blast::Xml>
+
+=item L<Bio::FastParsers::Blast::Xml::BlastOutput>
+
+=item L<Bio::FastParsers::Blast::Xml::Statistics>
+
+=item L<Bio::FastParsers::Blast::Xml::Parameters>
+
+=item L<Bio::FastParsers::Blast::Xml::Iteration>'s
+
+=item L<Bio::FastParsers::Blast::Xml::Hit>'s
+
+=item L<Bio::FastParsers::Blast::Xml::Hsp>'s
+
+=back
+
+Documentation is autogenerated.
 
 =head1 ATTRIBUTES
 
